==> groupoffice-com-4.0.97.tar.gz: groupoffice-com-4.0.97/language/countries/fr.inc.php <==
<?php
/////////////////////////////////////////////////////////////////////////////////
//
// Copyright Intermesh
// 
// This file is part of Group-Office. You should have received a copy of the
// Group-Office license along with Group-Office. See the file /LICENSE.TXT
// 
// If you have questions write an e-mail to info@intermesh.nl
//
// @copyright Copyright Intermesh
// @version $Id: fr.inc.php 8287 2011-10-12 12:03:09Z mschering $
// @author Merijn Schering <mschering@intermesh.nl>
//
// French Translation
// Version : 3.7.29 
// Author : Lionel JULLIEN
// Date : September, 27 2011
//
/////////////////////////////////////////////////////////////////////////////////

//Uncomment this line in new translations!
require($GLOBALS['GO_LANGUAGE']->get_fallback_base_language_file('countries'));

$countries['AD'] = 'Andorre';
$countries['AF'] = 'Afghanistan';
$countries['AG'] = 'Antigua et Barbuda';
$countries['AI'] = 'Anguilla';
$countries['AL'] = 'Albanie';
$countries['AM'] = 'Arménie';
$countries['AN'] = 'Antilles Néerlandaises';
$countries['AO'] = 'Angola';
$countries['AQ'] = 'Antarctique';
$countries['AR'] = 'Argentine';
$countries['AS'] = 'Samoa';
$countries['AT'] = 'Autriche';
$countries['AU'] = 'Australie';
$countries['AW'] = 'Aruba';
$countries['AZ'] = 'Azerbaïdjan';
$countries['BA'] = 'Bosnie Herzégovine';
$countries['BB'] = 'Barbade';
$countries['BD'] = 'Bangladesh';
$countries['BE'] = 'Belgique';
$countries['BF'] = 'Burkina Faso';
$countries['BG'] = 'Bulgarie';
$countries['BH'] = 'Bahreïn';
$countries['BI'] = 'Burundi';
$countries['BJ'] = 'Bénin';
$countries['BM'] = 'Bermudes';
$countries['BN'] = 'Brunei';
$countries['BO'] = 'Bolivie';
$countries['BR'] = 'Brésil';
$countries['BS'] = 'Bahamas';
$countries['BT'] = 'Bhoutan';
$countries['BV'] = 'Bouvet (Ile)';
$countries['BW'] = 'Botswana';
$countries['BY'] = 'Biélorussie';
$countries['BZ'] = 'Belize';
$countries['CA'] = 'Canada';
$countries['CC'] = 'Cocos (Keeling) (Iles)';
$countries['CF'] = 'République Centrafricaine';
$countries['CG'] = 'Congo';
$countries['CH'] = 'Suisse';
$countries['CI'] = 'Cote Ivoire';
$countries['CK'] = 'Cook (Iles)';
$countries['CL'] = 'Chili';
$countries['CM'] = 'Cameroun';
$countries['CO'] = 'Colombie';
$countries['CR'] = 'Costa Rica';
$countries['CU'] = 'Cuba';
$countries['CV'] = 'Cap Vert';
$countries['CX'] = 'Christmas (Ile)';
$countries['CY'] = 'Chypre';
$countries['CZ'] = 'République Tchèque';
$countries['DE'] = 'Allemagne';
$countries['DJ'] = 'Djibouti';
$countries['DK'] = 'Danemark';
$countries['DM'] = 'Dominica';
$countries['DO'] = 'République Dominicaine';
$countries['DZ'] = 'Algérie';
$countries['EC'] = 'Equateur';
$countries['EE'] = 'Estonie';
$countries['EG'] = 'Egypte';
$countries['EH'] = 'Sahara Occidental';
$countries['ER'] = 'Erythrée';
$countries['ES'] = 'Espagne';
$countries['ET'] = 'Ethiopie';
$countries['FI'] = 'Finlande';
$countries['FJ'] = 'Fiji';
$countries['FK'] = 'Falkland (Iles)';
$countries['FM'] = 'Micronésie';
$countries['FO'] = 'Féroé (Iles)';
$countries['FR'] = 'France';
$countries['FX'] = 'France Métropolitaine';
$countries['GA'] = 'Gabon';
$countries['GB'] = 'Royaume-Uni';
$countries['GD'] = 'Grenade';
$countries['GE'] = 'Géorgie';
$countries['GF'] = 'Guyane Française';
$countries['GH'] = 'Ghana';
$countries['GI'] = 'Gribraltar';
$countries['GL'] = 'Gröenland';
$countries['GM'] = 'Gambie';
$countries['GN'] = 'Guinée';
$countries['GP'] = 'Guadeloupe';
$countries['GQ'] = 'Guinée équatoriale';
$countries['GR'] = 'Grèce';
$countries['GS'] = 'Georgie du Sud - Iles Sandwich';
$countries['GT'] = 'Guatemala';
$countries['GU'] = 'Guam';
$countries['GW'] = 'Guinée Bissau';
$countries['GY'] = 'Guyane';
$countries['HK'] = 'Hong Kong';
$countries['HM'] = 'Heard et Mc Donald (Iles)';
$countries['HN'] = 'Honduras';
$countries['HR'] = 'Croatie';
$countries['HT'] = 'Haïti';
$countries['HU'] = 'Hongrie';
$countries['ID'] = 'Indonésie';
$countries['IE'] = 'Irlande';
$countries['IL'] = 'Israël';
$countries['IM'] = 'Man (Ile)';
$countries['IN'] = 'Inde';
$countries['IO'] = 'Inde Britanique Océanique';
$countries['IS'] = 'Islande';
$countries['IT'] = 'Italie';
$countries['JM'] = 'Jamaïque';
$countries['JO'] = 'Jordanie';
$countries['JP'] = 'Japon';
$countries['KE'] = 'Kenya';
$countries['KG'] = 'République Kirghize';
$countries['KH'] = 'Cambodge';
$countries['KI'] = 'Kiribati';
$countries['KM'] = 'Comores';
$countries['KN'] = 'Saint Kitts et Nevis';
$countries['KW'] = 'Koweït';
$countries['KY'] = 'Cayman (Iles)';
$countries['KZ'] = 'Kazakhstan';
$countries['LA'] = 'Laos';
$countries['LB'] = 'Liban';
$countries['LC'] = 'Sainte Lucie';
$countries['LI'] = 'Liechtenstein';
$countries['LK'] = 'Sri Lanka';
$countries['LR'] = 'Liberia';
$countries['LS'] = 'Lesotho';
$countries['LT'] = 'Lituanie';
$countries['LU'] = 'Luxembourg';
$countries['LV'] = 'Latvia';
$countries['LY'] = 'Libye';
$countries['MA'] = 'Maroc';
$countries['MC'] = 'Monaco';
$countries['MD'] = 'Moldavie';
$countries['MG'] = 'Madagascar';
$countries['MH'] = 'Marshall (Iles)';
$countries['MK'] = 'Macédoine';
$countries['ML'] = 'Mali';
$countries['MM'] = 'Myanmar';
$countries['MN'] = 'Mongolie';
$countries['MO'] = 'Macao';
$countries['MP'] = 'Mariannes (Iles)';
$countries['MQ'] = 'Martinique';
$countries['MR'] = 'Mauritanie';
$countries['MS'] = 'Monserrat';
$countries['MT'] = 'Malte';
$countries['MU'] = 'Maurice (Ile)';
$countries['MV'] = 'Maldives (Iles)';
$countries['MW'] = 'Malawi';
$countries['MX'] = 'Mexique';
$countries['MZ'] = 'Mozambique';
$countries['NA'] = 'Namibie';
$countries['NC'] = 'Nouvelle Calédonie';
$countries['NE'] = 'Niger';
$countries['NF'] = 'Norfolk (Ile)';
$countries['NG'] = 'Nigéria';
$countries['NI'] = 'Nicaragua';
$countries['NL'] = 'Pays-Bas';
$countries['NO'] = 'Norvège';
$countries['NP'] = 'Népal';
$countries['NR'] = 'Nauru';
$countries['NU'] = 'Niue';
$countries['NZ'] = 'Nouvelle-Zélande';
$countries['OM'] = 'Oman';
$countries['PA'] = 'Panama';
$countries['PE'] = 'Pérou';
$countries['PF'] = 'Polynésie';
$countries['PG'] = 'Papouasie-Nouvelle Guinée';
$countries['PH'] = 'Philippines';
$countries['PL'] = 'Pologne';
$countries['PM'] = 'St Pierre et Miquelon';
$countries['PN'] = 'Pitcairn';
$countries['PR'] = 'Puerto Rico';
$countries['PT'] = 'Portugal';
$countries['PW'] = 'Palau (Belau)';
$countries['PY'] = 'Paraguay';
$countries['QA'] = 'Qatar';
$countries['RE'] = 'Réunion';
$countries['RO'] = 'Roumanie';
$countries['RU'] = 'Fédération Russe';
$countries['RW'] = 'Rwanda';
$countries['SA'] = 'Arabie Saoudite';
$countries['SB'] = 'Salomon (Iles)';
$countries['SC'] = 'Seychelles';
$countries['SD'] = 'Soudan';
$countries['SE'] = 'Suède';
$countries['SG'] = 'Singapour';
$countries['SH'] = 'St Hélène';
$countries['SI'] = 'Slovénie';
$countries['SJ'] = 'Svalbard et Jan Mayen (Iles)';
$countries['SK'] = 'Slovaquie';
$countries['SL'] = 'Sierra Leone';
$countries['SM'] = 'San Marin';
$countries['SN'] = 'Sénégal';
$countries['SO'] = 'Somalie';
$countries['SR'] = 'Surinam';
$countries['ST'] = 'Sao tome et Principe';
$countries['SV'] = 'El Salvador';
$countries['SY'] = 'Syrie';
$countries['SZ'] = 'Swaziland';
$countries['TC'] = 'Turks et Caicos (Iles)';
$countries['TD'] = 'Tchad';
$countries['TG'] = 'Togo';
$countries['TH'] = 'Thaïlande';
$countries['TJ'] = 'Tadjikistan';
$countries['TK'] = 'Tokelau';
$countries['TM'] = 'Turkménistan';
$countries['TN'] = 'Tunisie';
$countries['TO'] = 'Tonga';
$countries['TP'] = 'Timor Est';
$countries['TR'] = 'Turquie';
$countries['TT'] = 'Trinité et Tobago';
$countries['TV'] = 'Tuvalu';
$countries['TW'] = 'Taiwan';
$countries['TZ'] = 'Tanzanie';
$countries['UA'] = 'Ukraine';
$countries['UG'] = 'Ouganda';
$countries['UM'] = 'Royaume-Uni';
$countries['US'] = 'Etats-Unis';
$countries['UY'] = 'Uruguay';
$countries['UZ'] = 'Ouzbékistan';
$countries['VA'] = 'Vatican';
$countries['VC'] = 'St Vincent et Grenadine';
$countries['VE'] = 'Venezuela';
$countries['VG'] = 'Vierges (Iles-GB)';
$countries['VI'] = 'Vierges (Iles-USA)';
$countries['VN'] = 'Vietnam';
$countries['VU'] = 'Vanuatu';
$countries['WF'] = 'Wallis et Futuna (Iles)';
$countries['WS'] = 'Samoa Occidental';
$countries['YE'] = 'Yémen';
$countries['YT'] = 'Mayotte';
$countries['YU'] = 'Serbie Monténegro';
$countries['ZA'] = 'Afrique du Sud';
$countries['ZM'] = 'Zambie';
$countries['ZR'] = 'Zaïre';
$countries['ZW'] = 'Zimbabwe';
$countries['AE'] = 'Émirats arabes unis';
$countries['AX'] = 'Åland, État libre associé d\'';
$countries['CN'] = 'Chine';
$countries['TF'] = 'French Southern Territories';
$countries['GG'] = 'Guernesey';
$countries['IR'] = 'Iran';
$countries['IQ'] = 'Iraq';
$countries['MY'] = 'Malaysie';
$countries['CD'] = 'République Démocratique du Congo';
$countries['KP'] = 'Corée, République populaire démocratique de';
$countries['KR'] = 'Corée, République de';
?>

==> groupoffice-com-4.0.144.tar.gz: groupoffice-com-4.0.144/language/countries/fr.inc.php <==
<?php
/////////////////////////////////////////////////////////////////////////////////
//
// Copyright Intermesh
// 
// This file is part of Group-Office. You should have received a copy of the
// Group-Office license along with Group-Office. See the file /LICENSE.TXT
// 
// If you have questions write an e-mail to info@intermesh.nl
//
// @copyright Copyright Intermesh
// @version $Id: fr.inc.php 12014 2012-09-20 16:01:48Z mschering $
// @author Merijn Schering <mschering@intermesh.nl>
//
// French Translation
// Version : 4.0.99
// Author : Lionel JULLIEN / Boris HERBINIERE-SEVE
// Date : September, 20 2012
//
/////////////////////////////////////////////////////////////////////////////////

//Uncomment this line in new translations!
require($GLOBALS['GO_LANGUAGE']->get_fallback_base_language_file('countries'));

$countries['AD'] = 'Andorre';
$countries['AF'] = 'Afghanistan';
$countries['AG'] = 'Antigua et Barbuda';
$countries['AI'] = 'Anguilla';
$countries['AL'] = 'Albanie';
$countries['AM'] = 'Arménie';
$countries['AN'] = 'Antilles Néerlandaises';
$countries['AO'] = 'Angola';
$countries['AQ'] = 'Antarctique';
$countries['AR'] = 'Argentine';
$countries['AS'] = 'Samoa';
$countries['AT'] = 'Autriche';
$countries['AU'] = 'Australie';
$countries['AW'] = 'Aruba';
$countries['AZ'] = 'Azerbaïdjan';
$countries['BA'] = 'Bosnie Herzégovine';
$countries['BB'] = 'Barbade';
$countries['BD'] = 'Bangladesh';
$countries['BE'] = 'Belgique';
$countries['BF'] = 'Burkina Faso';
$countries['BG'] = 'Bulgarie';
$countries['BH'] = 'Bahreïn';
$countries['BI'] = 'Burundi';
$countries['BJ'] = 'Bénin';
$countries['BM'] = 'Bermudes';
$countries['BN'] = 'Brunei';
$countries['BO'] = 'Bolivie';
$countries['BR'] = 'Brésil';
$countries['BS'] = 'Bahamas';
$countries['BT'] = 'Bhoutan';
$countries['BV'] = 'Bouvet (Ile)';
$countries['BW'] = 'Botswana';
$countries['BY'] = 'Biélorussie';
$countries['BZ'] = 'Belize';
$countries['CA'] = 'Canada';
$countries['CC'] = 'Cocos (Keeling) (Iles)';
$countries['CF'] = 'République Centrafricaine';
$countries['CG'] = 'Congo';
$countries['CH'] = 'Suisse';
$countries['CI'] = 'Cote Ivoire';
$countries['CK'] = 'Cook (Iles)';
$countries['CL'] = 'Chili';
$countries['CM'] = 'Cameroun';
$countries['CO'] = 'Colombie';
$countries['CR'] = 'Costa Rica';
$countries['CU'] = 'Cuba';
$countries['CV'] = 'Cap Vert';
$countries['CX'] = 'Christmas (Ile)';
$countries['CY'] = 'Chypre';
$countries['CZ'] = 'République Tchèque';
$countries['DE'] = 'Allemagne';
$countries['DJ'] = 'Djibouti';
$countries['DK'] = 'Danemark';
$countries['DM'] = 'Dominica';
$countries['DO'] = 'République Dominicaine';
$countries['DZ'] = 'Algérie';
$countries['EC'] = 'Equateur';
$countries['EE'] = 'Estonie';
$countries['EG'] = 'Egypte';
$countries['EH'] = 'Sahara Occidental';
$countries['ER'] = 'Erythrée';
$countries['ES'] = 'Espagne';
$countries['ET'] = 'Ethiopie';
$countries['FI'] = 'Finlande';
$countries['FJ'] = 'Fiji';
$countries['FK'] = 'Falkland (Iles)';
$countries['FM'] = 'Micronésie';
$countries['FO'] = 'Féroé (Iles)';
$countries['FR'] = 'France';
$countries['FX'] = 'France Métropolitaine';
$countries['GA'] = 'Gabon';
$countries['GB'] = 'Royaume-Uni';
$countries['GD'] = 'Grenade';
$countries['GE'] = 'Géorgie';
$countries['GF'] = 'Guyane Française';
$countries['GH'] = 'Ghana';
$countries['GI'] = 'Gribraltar';
$countries['GL'] = 'Gröenland';
$countries['GM'] = 'Gambie';
$countries['GN'] = 'Guinée';
$countries['GP'] = 'Guadeloupe';
$countries['GQ'] = 'Guinée équatoriale';
$countries['GR'] = 'Grèce';
$countries['GS'] = 'Georgie du Sud - Iles Sandwich';
$countries['GT'] = 'Guatemala';
$countries['GU'] = 'Guam';
$countries['GW'] = 'Guinée Bissau';
$countries['GY'] = 'Guyane';
$countries['HK'] = 'Hong Kong';
$countries['HM'] = 'Heard et Mc Donald (Iles)';
$countries['HN'] = 'Honduras';
$countries['HR'] = 'Croatie';
$countries['HT'] = 'Haïti';
$countries['HU'] = 'Hongrie';
$countries['ID'] = 'Indonésie';
$countries['IE'] = 'Irlande';
$countries['IL'] = 'Israël';
$countries['IM'] = 'Man (Ile)';
$countries['IN'] = 'Inde';
$countries['IO'] = 'Inde Britanique Océanique';
$countries['IS'] = 'Islande';
$countries['IT'] = 'Italie';
$countries['JM'] = 'Jamaïque';
$countries['JO'] = 'Jordanie';
$countries['JP'] = 'Japon';
$countries['KE'] = 'Kenya';
$countries['KG'] = 'République Kirghize';
$countries['KH'] = 'Cambodge';
$countries['KI'] = 'Kiribati';
$countries['KM'] = 'Comores';
$countries['KN'] = 'Saint Kitts et Nevis';
$countries['KW'] = 'Koweït';
$countries['KY'] = 'Cayman (Iles)';
$countries['KZ'] = 'Kazakhstan';
$countries['LA'] = 'Laos';
$countries['LB'] = 'Liban';
$countries['LC'] = 'Sainte Lucie';
$countries['LI'] = 'Liechtenstein';
$countries['LK'] = 'Sri Lanka';
$countries['LR'] = 'Liberia';
$countries['LS'] = 'Lesotho';
$countries['LT'] = 'Lituanie';
$countries['LU'] = 'Luxembourg';
$countries['LV'] = 'Latvia';
$countries['LY'] = 'Libye';
$countries['MA'] = 'Maroc';
$countries['MC'] = 'Monaco';
$countries['MD'] = 'Moldavie';
$countries['MG'] = 'Madagascar';
$countries['MH'] = 'Marshall (Iles)';
$countries['MK'] = 'Macédoine';
$countries['ML'] = 'Mali';
$countries['MM'] = 'Myanmar';
$countries['MN'] = 'Mongolie';
$countries['MO'] = 'Macao';
$countries['MP'] = 'Mariannes (Iles)';
$countries['MQ'] = 'Martinique';
$countries['MR'] = 'Mauritanie';
$countries['MS'] = 'Monserrat';
$countries['MT'] = 'Malte';
$countries['MU'] = 'Maurice (Ile)';
$countries['MV'] = 'Maldives (Iles)';
$countries['MW'] = 'Malawi';
$countries['MX'] = 'Mexique';
$countries['MZ'] = 'Mozambique';
$countries['NA'] = 'Namibie';
$countries['NC'] = 'Nouvelle Calédonie';
$countries['NE'] = 'Niger';
$countries['NF'] = 'Norfolk (Ile)';
$countries['NG'] = 'Nigéria';
$countries['NI'] = 'Nicaragua';
$countries['NL'] = 'Pays-Bas';
$countries['NO'] = 'Norvège';
$countries['NP'] = 'Népal';
$countries['NR'] = 'Nauru';
$countries['NU'] = 'Niue';
$countries['NZ'] = 'Nouvelle-Zélande';
$countries['OM'] = 'Oman';
$countries['PA'] = 'Panama';
$countries['PE'] = 'Pérou';
$countries['PF'] = 'Polynésie';
$countries['PG'] = 'Papouasie-Nouvelle Guinée';
$countries['PH'] = 'Philippines';
$countries['PL'] = 'Pologne';
$countries['PM'] = 'St Pierre et Miquelon';
$countries['PN'] = 'Pitcairn';
$countries['PR'] = 'Puerto Rico';
$countries['PT'] = 'Portugal';
$countries['PW'] = 'Palau (Belau)';
$countries['PY'] = 'Paraguay';
$countries['QA'] = 'Qatar';
$countries['RE'] = 'Réunion';
$countries['RO'] = 'Roumanie';
$countries['RU'] = 'Fédération Russe';
$countries['RW'] = 'Rwanda';
$countries['SA'] = 'Arabie Saoudite';
$countries['SB'] = 'Salomon (Iles)';
$countries['SC'] = 'Seychelles';
$countries['SD'] = 'Soudan';
$countries['SE'] = 'Suède';
$countries['SG'] = 'Singapour';
$countries['SH'] = 'St Hélène';
$countries['SI'] = 'Slovénie';
$countries['SJ'] = 'Svalbard et Jan Mayen (Iles)';
$countries['SK'] = 'Slovaquie';
$countries['SL'] = 'Sierra Leone';
$countries['SM'] = 'San Marin';
$countries['SN'] = 'Sénégal';
$countries['SO'] = 'Somalie';
$countries['SR'] = 'Surinam';
$countries['ST'] = 'Sao tome et Principe';
$countries['SV'] = 'El Salvador';
$countries['SY'] = 'Syrie';
$countries['SZ'] = 'Swaziland';
$countries['TC'] = 'Turks et Caicos (Iles)';
$countries['TD'] = 'Tchad';
$countries['TG'] = 'Togo';
$countries['TH'] = 'Thaïlande';
$countries['TJ'] = 'Tadjikistan';
$countries['TK'] = 'Tokelau';
$countries['TM'] = 'Turkménistan';
$countries['TN'] = 'Tunisie';
$countries['TO'] = 'Tonga';
$countries['TP'] = 'Timor Est';
$countries['TR'] = 'Turquie';
$countries['TT'] = 'Trinité et Tobago';
$countries['TV'] = 'Tuvalu';
$countries['TW'] = 'Taiwan';
$countries['TZ'] = 'Tanzanie';
$countries['UA'] = 'Ukraine';
$countries['UG'] = 'Ouganda';
$countries['UM'] = 'Royaume-Uni';
$countries['US'] = 'Etats-Unis';
$countries['UY'] = 'Uruguay';
$countries['UZ'] = 'Ouzbékistan';
$countries['VA'] = 'Vatican';
$countries['VC'] = 'St Vincent et Grenadine';
$countries['VE'] = 'Venezuela';
$countries['VG'] = 'Vierges (Iles-GB)';
$countries['VI'] = 'Vierges (Iles-USA)';
$countries['VN'] = 'Vietnam';
$countries['VU'] = 'Vanuatu';
$countries['WF'] = 'Wallis et Futuna (Iles)';
$countries['WS'] = 'Samoa Occidental';
$countries['YE'] = 'Yémen';
$countries['YT'] = 'Mayotte';
$countries['YU'] = 'Serbie Monténégro';
$countries['ZA'] = 'Afrique du Sud';
$countries['ZM'] = 'Zambie';
$countries['ZR'] = 'Zaïre';
$countries['ZW'] = 'Zimbabwe';
$countries['AE'] = 'Émirats arabes unis';
$countries['AX'] = 'Åland, État libre associé d\'';
$countries['CN'] = 'Chine';
$countries['TF'] = 'French Southern Territories';
$countries['GG'] = 'Guernesey';
$countries['IR'] = 'Iran';
$countries['IQ'] = 'Iraq';
$countries['MY'] = 'Malaysie';
$countries['CD'] = 'République Démocratique du Congo';
$countries['KP'] = 'Corée, République populaire démocratique de';
$countries['KR'] = 'Corée, République de';
$countries['MY']= 'Malaisie';
$countries['RS']= 'République de Serbie';
$countries['ME']= 'République du Monténégro';
?>
